@@ -15,9 +15,9 @@
  */
  
 // Enable for debug output
-//#define DEBUG
+//#define AUDIO_SCAN_DEBUG
 
-#ifdef DEBUG
+#ifdef AUDIO_SCAN_DEBUG
 # define DEBUG_TRACE(...) PerlIO_printf(PerlIO_stderr(), __VA_ARGS__)
 #else
 # define DEBUG_TRACE(...)
@@ -48,10 +48,6 @@ typedef struct _GUID {
 
 #include "buffer.h"
 
-#ifdef _MSC_VER
-# define stat _stat
-#endif
-
 /* strlen the length automatically */
 #define my_hv_store(a,b,c)     hv_store(a,b,strlen(b),c,0)
 #define my_hv_store_ent(a,b,c) hv_store_ent(a,b,c,0)
@@ -72,3 +68,4 @@ extern int _check_buf(PerlIO *infile, Buffer *buf, int size, int min_size);
 extern void _split_vorbis_comment(char* comment, HV* tags);
 extern int32_t skip_id3v2(PerlIO *infile);
 extern uint32_t _bitrate(uint32_t audio_size, uint32_t song_length_ms);
+extern off_t _file_size(PerlIO *infile);
